@@ -14,7 +14,7 @@ symlink "os/Solaris.c", "OS.c" || die "Could not link os/Solaris.c to os/OS.c\n"
 # If this OS version supports the new /proc filesystem, use it; 
 # otherwise default to ioctl-proc
 `uname -r` =~ /^(\d+\.\d+)/;
-if( $1 > 5.5 ){
+if( $1 !~ /^5.[012345]$/ ){
     $self->{DEFINE} = $self->{DEFINE} . " -DPROC_FS";
 }
 
